@@ -5,6 +5,7 @@ import shutil
 import click
 
 from nile.commands.compile import compile_command
+from nile.commands.init import init_command
 from nile.commands.install import install_command
 from nile.commands.test import test_command
 from nile.common import BUILD_DIRECTORY
@@ -17,10 +18,15 @@ def cli():
 
 
 @cli.command()
-@click.argument("tag")
-def install(tag):
-    """Install TAG version of Cairo."""
-    install_command(tag)
+def init():
+    """Nile CLI group."""
+    init_command()
+
+
+@cli.command()
+def install():
+    """Install Cairo."""
+    install_command()
 
 
 @cli.command()
